===========
Customforms
===========

Customforms is a simple Django app to attach forms to pages.

Quick start
-----------

1. install django-wagtail-customforms from https://pypi.python.org/pypi/django-wagtail-customforms

    pip install django-wagtail-customforms

2. Add "customforms" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'customforms',
    ]

3. Check out the example app for usage.

4. Run `python manage.py migrate` once your models are set up.
